.CHAPTER RT11/TSX OPERATING PROCEDURES
.index Operation
.hl 1 INITIATING RUNOFF
.ifnot small
.br;RUNOFF may be initiated by any standard means.  The _.SAV image file
must be present to run the program.  Also, sufficient memory space must be
available to accomadate RUNOFF code and data.  If the program will not load
and run, it must be relinked to overlay parts of the program from disk.
If the program loads and runs but will not process input files then there
may not be sufficient dynamic memory (memory that is used by RUNOFF to
temporarily store indices, footnotes, substitutions, etc_.).  If this is
the case then the program must be relinked to make more memory available
for temporary storage.  If this fails, then the program is probably too
large to run on your system.
.endif small
 RUNOFF may be initiated by:
.nofill
.s.c ;RUN DEV:RUNOFF_.SAV
.s.c ;or
.s.c ;@COMMND_.COM
.fill
.s;where DEV: is the device on which the RUNOFF_.SAV file is found and
COMMND_.COM is a command file which initiates RUNOFF and may or may not
contain file specification information.
.hl 1 COMMAND STRING
.index COMMAND STRING
.br;After initiating RUNOFF, the program will prompt you for a
command string. The command string specifies the names of the input
and output files and any options which you may select at run time.
The standard command string (for further information look at the
_.CSIGEN macro in the Programmer's Reference Manual) should be
entered in the following form:
.skip
.nofill
.c ;output-file,toc-file=input-file,input-file,,,,input-file/options
.skip
.fill
where output-file is the document to be produced by RUNOFF, toc-file is
a table of contents file which may be edited before it is reprocessed by
RUNOFF to produce a table of contents, and input-file is a file containing
text and RUNOFF commands that control the format of the output-file
and the toc-file.  
.ifnot small
Up to six input-files may be concatenated to produce
a single document file.  Each input file is processed sequentially and
no parameters are reset between files.
This feature allows control files for different printers to be
processed prior to the text.
Users should construct a control file for each printer with the
appropriate escape sequence definitions and printer specific RUNOFF
commands such as _.PAPER SIZE.
Thus, no file editing will be required to print documents on
two printers or terminals which may have different capabilities.
Also, control files may be built to
set parameters for different types of documents (for example: business
letters, technical documentation, or a masters thesis).
For example:
.skip
.c ;DK:THESIS,DK:THESIS=DK:SPIN,DK:CONTRL,DK:THESIS
.skip
where SPIN will define escape sequences for a
NEC Spinwriter printer and set the paper size, and CONTRL will contain
RUNOFF commands to format the document in the customary thesis form.
.skip
The toc-file may be omitted if no table of contents is desired.
The available options may be printed on the user's terminal by entering
only a /I in response to the CSI prompt.
The user may exit the program back to the operating system
by typing a /X.
.endif small
.br.hl 2 FILE SPECIFICATIONS
.index File Specifications
A valid file specification has the following form:
.nofill
.skip
.c ;DEV:FILNAM.EXT
.skip
.fill
.ifnot small
For this file specification DEV: must be a legal device code.
The default device code is DK: where DK: may be assigned to any
device found on the system.  The output-file, toc-file, and input-files
may be on different devices.
The FILNAM may be any 1 to 6 character alphanumeric string and EXT may
be any 1 to 3 character alphanumeric string.  FILNAM and EXT must be
separated by a period.  The default EXT's are RNO for the input-files,
DOC for the output-file, and RNT for the table of contents file.
Normally only the FILNAM need be specified.
The table of contents file must be processed by RUNOFF as an input-file
to produce a table of contents (or DOC file).
.skip
.note Editing RUNOFF Input and Output
The DOC file may be edited,
prior to printing, by any standard RT11 text editor to change the format
or contents of the DOC file.
Also, the RNT file may be edited to change the contents or format of the
table of contents to be produced by RUNOFF.
.skip
By virtue of the manner in which RUNOFF processes text files (line by
line) no single input line may be more than 512 characters long.
A line is defined as being text terminated by a carriage return and a
line feed.
A line may consist of several sentences or a part of a single sentence.
It is good practice (to facilitate future editing) to enter only single
sentences separated by a carriage return and a line feed.
Sentences longer than one screen width may contain as many carriage return
- line feed combinations as necessary.
.en
.endif small
.br.hl 2 OPTIONS
.index Options
.index SWITCHES
A command string may have one or more switch options associated
with it.
.ifnot small
A switch option consists of a / and a single ASCII character.
Also, some switch options may be followed by
a colon and a decimal number or an ASCII character.
Any decimal number may be preceded by a + or - sign and must be
followed by a period.
.skip
.endif small
The valid switch options are:
.skip
.nofill
.ts +10,+10,+10
/P:l:h	Output only the indicated page range.
.ifnot small
	l = lowest page to print
	h = highest page to print
	This option should be used in conjunction with the
	/A and /C options for chapter oriented text.
.skip
.endif small
/C:l:h	Output only the indicated chapter range.
.ifnot small.skip
.endif small
/A:l:h	Output only the indicated appendix range.
.ifnot small.skip
.endif small
.index Case
/G	Force all text to be output in uppercase.
/G:N	Allow all text to be output as it is input.
.ifnot small.skip
.endif small
.index Formfeeds
/F	Print standard ascii formfeed character.
/F:n	Simulate formfeed character with multiple linefeeds.
.ifnot small
	n = paper length
.skip
.endif small
.index Hyphenation
/H	Hyphenate output.
/H:N	Do not hyphenate output.
.ifnot small
	Note: This switch overrides .ENABLE HYPHENATION
.skip
.endif small
.index Right Shift
/R:n	Right shift output n spaces.
.ifnot small
	Useful for output that is to be bound.
.skip
.endif small
.index Page Size
/S:h:w	Set hardware page size.
.ifnot small
	h = height of page
	w = width of page
.skip
.endif small
.index Underlining
/U:B	Underline with underline character and backspace.
/U:L	Underline with underline character and line overprint.
/U:S	Underline with hyphen on next line.
/U:N	Do not underline text.
.ifnot small
	Note: This command overrides the enable underline command.
.skip
.endif small
/W	Wait for carriage return between pages.
/W:N	Do not wait for carriage return.
.ifnot small.skip
.endif small
/I	Print available switch options on terminal.
.ifnot small.skip
.endif small
/E	Output even pages
/E:N	Do not output even pages
.ifnot small.skip
.endif small
/O	Output odd pages
/O:N	Do not output odd pages
.ifnot small.skip
.endif small
/X	Exit program and return to operating system.
.ifnot small.skip
.endif small
/2	Perform 2 passes.
/2:N	Perform 1 pass.
.ifnot small.skip
.endif small
/M	Output warning messages
/M:N	Suppress warning messages
.ifnot small.skip
.endif small
.index Defaults
Default values are: /G:N/F/H/R:0./S:58.:60./U:L/W:N/E/O/M/2:N (print all)
.fill
